#
# spec file for package opensesame
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opensesame
Version:        3.2.5
Release:        2.4
Summary:        Graphical experiment builder for the social sciences
License:        GPL-3.0-only AND Apache-2.0 AND GPL-2.0-or-later AND OFL-1.1
Group:          Productivity/Scientific/Other
URL:            https://github.com/smathot/OpenSesame/
Source0:        https://github.com/smathot/OpenSesame/archive/release/%{version}.tar.gz#/OpenSesame-release-%{version}.tar.gz
# PATCH-FIX-UPSTREAM invalid-desktopfile.patch avvissu@yandex.ru-- Add semicolon (';') as trailing character
Patch0:         opensesame-2.9.6_invalid-desktopfile.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-PyYAML
BuildRequires:  python3-base
BuildRequires:  python3-pygame >= 1.8.1
BuildRequires:  python3-qscintilla
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python3-PyYAML
Requires:       python3-markdown
Requires:       python3-numpy >= 1.3.0
Requires:       python3-pygame >= 1.8.1
Requires:       python3-qprogedit >= 3.0.0
Requires:       python3-qt5
Requires:       python3-simplejson
Requires:       python3-webcolors
Recommends:     IPython
Recommends:     python-Pillow >= 1.1.7
Recommends:     python-PsychoPy >= 1.64.0
Recommends:     python-PyAudio
Recommends:     python-expyriment >= 0.5.2
Recommends:     python-opengl >= 3.0.1
Recommends:     python-pyserial >= 2.3.0
BuildArch:      noarch

%description
OpenSesame is a graphical experiment builder for the social sciences.
It sports a user interface that allows building complex experiments.
A wide range of experiments can be created with OpenSesame. The
plug-in framework and Python scripting allow incorporating external
devices, such as eye trackers, response boxes, and parallel port
devices, into experiments.

%prep
%setup -q -n OpenSesame-release-%{version}
%patch0 -p1

%build
%python3_build

%install
%python3_install

# Use path of %%license macro
rm -f %{buildroot}%{_datadir}/%{name}/COPYING

pushd mime
%suse_update_desktop_file -i opensesame
install -Dm 644 x-opensesame-experiment.xml %{buildroot}%{_datadir}/mime/packages/x-opensesame-experiment.xml
popd

%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING copyright
%{_bindir}/opensesame
%{_bindir}/opensesamerun
%{_datadir}/opensesame_extensions/
%{_datadir}/opensesame_plugins/
%{_datadir}/opensesame_resources/
%{_datadir}/applications/opensesame.desktop
%{_datadir}/icons/hicolor/scalable/apps/opensesame.svg
%{_datadir}/mime/packages/x-opensesame-experiment.xml
%{python3_sitelib}/openexp/
%{python3_sitelib}/libopensesame/
%{python3_sitelib}/libqtopensesame/
%{python3_sitelib}/python_opensesame-%{version}-*.egg-info

%changelog
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and generalize description.
* Wed Dec  5 2018 Todd R <toddrme2178@gmail.com>
- Update to 3.2.5
- Rebase opensesame-2.9.6_invalid-desktopfile.patch
* Tue Jul 12 2016 avvissu@yandex.by
- Update to 3.0.7:
  * Fix 'sound' duration in sampler and sketchpad (#401)
  * Correctly escape slashes in OpenSesame syntax (#403)
  * Don't crash on viewing remote urls ending in .md
  * Fix crashing help menu when off-line (#395)
  * Preserve cursor position when switching to and from inline_script
  items (#390)
  * Give better error message when missing end-of-block line for
    multiline variables
* Sat Mar 12 2016 avvissu@yandex.ru
- Remove python-markdown from recommends
* Fri Feb 26 2016 avvissu@yandex.ru
- Update to 3.0.6:
  * release includes various bugfixes
* Tue Jan 12 2016 avvissu@yandex.ru
- Update to 3.0.5:
  * release includes various bugfixes
* Fri Dec  4 2015 avvissu@yandex.ru
- Update to 3.0.4:
  * release includes various bugfixes
* Fri Nov  6 2015 avvissu@yandex.ru
- Update to 3.0.2:
  * improved validation of variable names in loop item
  * improved validation of OpenSesame-script syntax
  * improved exception handling (including run-status emoticons)
- Change in 3.0.1:
  * give more informative error messages when using invalid variable
    names
  * update auto_example plugin
  * ignore 'undefined name' warnings when validating Python code
    (requires QProgEdit >= 3.1.0)
  * update srbox plugin and add require_state_change_option
  * add explanation how to suppress bug_report messages
- Add Requires: python-webcolors
* Fri Aug 21 2015 avvissu@yandex.ru
- Update to 2.9.7:
  * add append menu to overview and sequence
  * add permanently delete menu option to unused items
  * includes various bugfixes
* Wed Jun  3 2015 avvissu@yandex.ru
- Initial package
